==> nouislider-9.2.0.jar: META-INF/resources/webjars/nouislider/9.2.0/documentation/download.php <==
<?php
	$title = "noUiSlider - Download noUiSlider for free!";
	$description = "Download the latest version of noUiSlider safely from gitHub. For free!";
?>

<h1>Download noUiSlider</h1>

<section>

	<div class="view">

		<p>noUiSlider is open source, and you can use it <strong>for free</strong> in any personal or commercial product. No attribution required. Both the uncompressed and compressed version of noUiSlider are available in a <code>.zip</code> release, which is hosted by Github and available over <code>https</code>.</p>

		<a class="button" href="https://github.com/leongersen/noUiSlider/releases/download/9.2.0/noUiSlider.9.2.0.zip" data-category="convert" data-action="download">Download noUiSlider from Github</a>

		<div class="share">
			<iframe src="https://ghbtns.com/github-btn.html?user=leongersen&repo=noUiSlider&type=star&count=true&size=large" frameborder="0" scrolling="0" width="160px" height="30px"></iframe>

			<a href="https://twitter.com/share" class="twitter-share-button" data-url="http://refreshless.com/nouislider/" data-text="Check out this responsive JavaScript range slider with touch support: #noUiSlider" data-size="large">Tweet</a>
		</div>

	</div>
</section>


<section>
	<a href="/nouislider/contact/">Help and contact</a>
	<br>
	<a href="/nouislider/new-version/">Release information about the latest Version</a>
	<br>
	Run the unit tests: <a href="/nouislider/tests/range.html">range</a> and <a href="/nouislider/tests/slider.html">slider</a>.
</section>


<h2>License</h2>

<section>

	<div class="view">

		<p>You can use noUiSlider for free, under the terms of the <a data-category="outlink" data-action="license" href="http://www.wtfpl.net/about/">WTFPL</a>, which allows everything and has no additional restrictions.</p>
	</div>
</section>


<h2>Repository</h2>

<section>

	<div class="view">

		<p>You can also visit the repository: <a data-category="convert" data-action="gitHub" href="https://github.com/leongersen/noUiSlider/">noUiSlider on gitHub</a>. If you need help implementing noUiSlider in your website, or if you'd like to see a new feature, feel free to ask me on twitter: <a data-category="convert" data-action="twitter" href="https://twitter.com/LeonGersen">@LeonGersen</a>.</p>
	</div>
</section>

<script src="https://platform.twitter.com/widgets.js"></script>

==> nouislider-11.0.0.jar: META-INF/resources/webjars/nouislider/11.0.0/documentation/download.php <==
<?php
	$title = "noUiSlider - Download noUiSlider for free!";
	$description = "Download the latest version of noUiSlider safely from gitHub. For free!";
?>

<h1>Download noUiSlider</h1>

<section>

	<div class="view">

		<p>noUiSlider is open source, and you can use it <strong>for free</strong> in any personal or commercial product. No attribution required. Both the uncompressed and compressed version of noUiSlider are available in a <code>.zip</code> release, which is hosted by Github and available over <code>https</code>.</p>

		<a class="button" href="https://github.com/leongersen/noUiSlider/releases/download/11.0.0/noUiSlider.11.0.0.zip" data-category="convert" data-action="download">Download noUiSlider from Github</a>

		<div class="share">
			<iframe src="https://ghbtns.com/github-btn.html?user=leongersen&repo=noUiSlider&type=star&count=true&size=large" frameborder="0" scrolling="0" width="160px" height="30px"></iframe>

			<a href="https://twitter.com/share" class="twitter-share-button" data-url="http://refreshless.com/nouislider/" data-text="Check out this responsive JavaScript range slider with touch support: #noUiSlider" data-size="large">Tweet</a>
		</div>

	</div>
</section>


<section>
	<a href="/nouislider/contact/">Help and contact</a>
	<br>
	<a href="/nouislider/new-version/">Release information about the latest Version</a>
	<br>
	Run the unit tests: <a href="/nouislider/tests/range.html">range</a> and <a href="/nouislider/tests/slider.html">slider</a>.
</section>


<h2>License</h2>

<section>

	<div class="view">

		<p>You can use noUiSlider for free, under the terms of the <a data-category="outlink" data-action="license" href="http://www.wtfpl.net/about/">WTFPL</a>, which allows everything and has no additional restrictions.</p>
	</div>
</section>


<h2>Repository</h2>

<section>

	<div class="view">

		<p>You can visit the repository: <a data-category="convert" data-action="gitHub" href="https://github.com/leongersen/noUiSlider/">noUiSlider on gitHub</a>. If you need help implementing noUiSlider in your website, or if you'd like to see a new feature, feel free to ask me on twitter: <a data-category="convert" data-action="twitter" href="https://twitter.com/LeonGersen">@LeonGersen</a>.</p>
	</div>
</section>

<script src="https://platform.twitter.com/widgets.js"></script>
